/***********************************************************************************************************************
 *
 * OpenBlueSky - NetBeans Platform Enhancements
 * Copyright (C) 2006-2011 by Tidalwave s.a.s. (http://www.tidalwave.it)
 *
 ***********************************************************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 *
 ***********************************************************************************************************************
 *
 * WWW: http://openbluesky.kenai.com
 * SCM: https://bitbucket.org/tidalwave/openbluesky-src
 *
 **********************************************************************************************************************/
package it.tidalwave.netbeans.rendezvous.notifier;

import it.tidalwave.netbeans.rendezvous.*;
import it.tidalwave.netbeans.rendezvous.RendezVous.Tag;
import javax.annotation.Nonnull;
import org.jdesktop.animation.timing.TimingTargetAdapter;

/***********************************************************************************************************************
 *
 * This class must be constructed by the same thread that starts the animator.
 *
 * @author  Fabrizio Giudici
 * @version $Id$
 *
 **********************************************************************************************************************/
public class EndAnimationNotifier extends TimingTargetAdapter
  {
    @Nonnull
    private final RendezVous rendezVous;

    @Nonnull
    private final String eventName;

    @Nonnull
    private final Tag tag;

    public EndAnimationNotifier (@Nonnull final RendezVous rendezVous,
                                      @Nonnull final String eventName)
      {
        this.rendezVous = rendezVous;
        this.eventName = eventName;
        tag = Tag.get();
      }

    @Override
    public void end()
      {
        try
          {
            Tag.set(tag);
            rendezVous.notifyEventOccurred(eventName);
          }
        finally
          {
            Tag.set(null);
          }
      }
  }
