/***********************************************************************************************************************
 *
 * OpenBlueSky - NetBeans Platform Enhancements
 * Copyright (C) 2006-2011 by Tidalwave s.a.s. (http://www.tidalwave.it)
 *
 ***********************************************************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 *
 ***********************************************************************************************************************
 *
 * WWW: http://openbluesky.kenai.com
 * SCM: https://bitbucket.org/tidalwave/openbluesky-src
 *
 **********************************************************************************************************************/
package it.tidalwave.netbeans.rendezvous.notifier;

import it.tidalwave.netbeans.rendezvous.*;
import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;
import java.util.Arrays;
import java.util.HashSet;
import java.util.Set;
import javax.annotation.Nonnull;

/***********************************************************************************************************************
 *
 * @author  Fabrizio Giudici
 * @version $Id$
 *
 **********************************************************************************************************************/
public class PropertyChangedNotifier implements PropertyChangeListener
  {
    @Nonnull
    private final RendezVous rendezVous;

    @Nonnull
    private final String eventName;

    @Nonnull
    private final Set<String> acceptedPropertyNames;

    public PropertyChangedNotifier (@Nonnull final RendezVous rendezVous,
                                    @Nonnull final String eventName,
                                    @Nonnull final String ... acceptedPropertyNames)
      {
        this.rendezVous = rendezVous;
        this.eventName = eventName;
        this.acceptedPropertyNames = new HashSet<String>(Arrays.asList(acceptedPropertyNames));
      }

    public void propertyChange (@Nonnull final PropertyChangeEvent event)
      {
        if (acceptedPropertyNames.contains(event.getPropertyName()))
          {
            rendezVous.notifyEventOccurred(eventName);
          }
      }
  }
